#!/bin/bash
# Script to fetch current values from Zeversolar/Zeverlution PV transformer on local LAN
# v1.0 2018-10-19 Ath

# Address of the Zeverlution inverter
ZEVERADDR=192.168.1.23
# Domoticz IDX values: IDX1 = type: Usage, 'PV now' (unused), IDX2 = type: Usage, 'PV Vandaag', IDX3 = type: General, Text, 'PV Opbrengst', IDX4 = type: General, Custom sensor, 'PV Nu'
IDX1=2456
IDX2=2457
IDX3=2459
IDX4=2460
DOMOTICZ=http://localhost:8080
# base64 encoded PI username and password
usere=
passe=
# helper file
emptyvaluefile=/home/pi/sent_empty_value
startuptimefile=/home/pi/startup_time_value
lastpotfile=/home/pi/last_pot_value

sendout=0

# Get the data
data=`wget -q -O - $ZEVERADDR/home.cgi`
# Only update if PV is available
if [ "$data" != "" ]; then
  sendout=1
fi
# Split up lines into an array
IFS=$'\n' lines=($data)

#echo -e "Data:\n$data\n"

# Select the desired fields (lines)
ser=${lines[9]}
pac=${lines[10]}
pot=${lines[11]}
var=$(awk -v m=$pot 'BEGIN { print m * 1000 }')
# If no proper values found don't update
if [ "$ser" = "" -o "$pac" = "" ]; then
  if [ -f "$emptyvaluefile" ]; then
    sendout=0
  else
    sendout=1
  fi
else
  if [ -f "$emptyvaluefile" ]; then
    rm "$emptyvaluefile"
    now=$(date +"%H:%M")
    echo $now>"$startuptimefile"
    echo 0>"$lastpotfile"
  fi
fi

# Display values to output
echo -e "Serial\t: $ser"
echo -e "Power\t: $pac watt"
echo -e "Today\t: $pot kWh $var Wh"
echo -e "Sendout\t: $sendout (1=yes, 0=no)"

if [ "$pot" != "" ]; then
  echo $pot>"$lastpotfile"
fi

# Send to Domoticz if proper data
if [ $sendout = 1 ]; then
  echo Sending data to Domoticz...
  # Power sensor (Now)
  if [ "$IDX1" != "" ]; then
    curl --silent --output /dev/null --show-error -i -H "Accept: application/json" "$DOMOTICZ/json.htm?username=$usere&password=$passe&type=command&param=udevice&idx=$IDX1&nvalue=0&svalue=$pac;$var"
  fi
  # Custom sensor
  if [ "$IDX4" != "" ]; then
    curl --silent --output /dev/null --show-error -i -H "Accept: application/json" "$DOMOTICZ/json.htm?username=$usere&password=$passe&type=command&param=udevice&idx=$IDX4&nvalue=0&svalue=$pac;$var"
  fi
  # Power sensor (Today)
  if [ "$IDX2" != "" ]; then
    curl --silent --output /dev/null --show-error -i -H "Accept: application/json" "$DOMOTICZ/json.htm?username=$usere&password=$passe&type=command&param=udevice&idx=$IDX2&nvalue=0&svalue=$var;$W"
  fi
  # Send to separate display
  lastpot=`cat $lastpotfile`
  /home/pi/sendtoespdisplay.sh $pac $lastpot
  if [ "$lastpot" != "" -a "$IDX3" != "" ]; then
    # Text sensor displaying both values
    curl --silent --output /dev/null --show-error -i -H "Accept: application/json" "$DOMOTICZ/json.htm?username=$usere&password=$passe&type=command&param=udevice&idx=$IDX3&nvalue=0&svalue=Nu%3A%20$pac%20Watt%20Vandaag%3A%20$lastpot%20kWh"
  fi
  echo Done.

  if [ "$ser" = "" -o "$pac" = "" ]; then
    touch "$emptyvaluefile"
  fi

fi
